@@ -29,11 +29,11 @@
 
 #include "kmime_util.h"
 #include "kmime_util_p.h"
-#include "kmime_codecs.h"
+#include "kmime_codecs_p.h"
 #include "kmime_content.h"
 #include "kmime_headerfactory_p.h"
 #include "kmime_debug.h"
-#include "kmime_warning.h"
+#include "kmime_warning_p.h"
 
 #include <KCodecs>
 
@@ -686,7 +686,7 @@ QByteArray PhraseList::as7BitString(bool withHeaderType) const
 
     for (int i = 0; i < d->phraseList.count(); ++i) {
         // FIXME: only encode when needed, quote when needed, etc.
-        rv += encodeRFC2047String(d->phraseList[i], d->encCS, false, false);
+        rv += encodeRFC2047String(d->phraseList[i], d->encCS, false);
         if (i != d->phraseList.count() - 1) {
             rv += ", ";
         }
@@ -847,14 +847,8 @@ QByteArray Parametrized::as7BitString(bool withHeaderType) const
             addQuotes(tmp, true);   // force quoting, eg. for whitespaces in parameter value
             rv += tmp;
         } else {
-            if (useOutlookAttachmentEncoding()) {
-                rv += it.key().toLatin1() + '=';
-                qCDebug(KMIME_LOG) << "doing:" << it.value() << QLatin1String(d->encCS);
-                rv += "\"" + encodeRFC2047String(it.value(), d->encCS) + "\"";
-            } else {
-                rv += it.key().toLatin1() + "*=";
-                rv += encodeRFC2231String(it.value(), d->encCS);
-            }
+            rv += it.key().toLatin1() + "*=";
+            rv += encodeRFC2231String(it.value(), d->encCS);
         }
     }
 
